@@ -116,7 +116,10 @@ def predict(
 
 
 def send_feedback(
-    user_model: Any, request: prediction_pb2.Feedback, predictive_unit_id: str
+    user_model: Any,
+    request: prediction_pb2.Feedback,
+    predictive_unit_id: str,
+    seldon_metrics: SeldonMetrics,
 ) -> prediction_pb2.SeldonMessage:
     """
 
@@ -133,6 +136,8 @@ def send_feedback(
     -------
 
     """
+    seldon_metrics.update_reward(request.reward)
+
     if hasattr(user_model, "send_feedback_rest"):
         logger.warning("send_feedback_rest is deprecated. Please use send_feedback_raw")
         request_json = json_format.MessageToJson(request)
